# Biogeme
![PyPI](https://img.shields.io/pypi/v/biogeme.svg)
[![Downloads](https://static.pepy.tech/badge/Biogeme)](https://pepy.tech/project/Biogeme)
[![Downloads](https://static.pepy.tech/badge/Biogeme/month)](https://pepy.tech/project/Biogeme)
[![Downloads](https://static.pepy.tech/badge/Biogeme/week)](https://pepy.tech/project/Biogeme)

Biogeme is an open source freeware designed for the maximum likelihood estimation of parametric models in general, 
with a special emphasis on discrete choice models.

## Install
Biogeme requires Python >= 3.10 and can be installed [from PyPI](https://pypi.org/project/biogeme/).

`pip install biogeme`

Installing Biogeme from source can be done after cloning the repository with the following command executed in the 
root directory:

`pip install .`

## Documentation
Further documentation is available on [biogeme.epfl.ch](https://biogeme.epfl.ch)

## Author
[Michel Bierlaire](https://people.epfl.ch/michel.bierlaire), [Ecole Polytechnique Fédérale de Lausanne](https://www.epfl.ch), Switzerland.

